def _tms():

    return {
        'arizona': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'arizona-cardinals': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'st-louis-cardinals': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'phoenix-cardinals': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'phoenix': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'cardinals': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'ari': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'crd': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'atlanta': {
            'market': 'Atlanta',
            'name': 'Falcons',
            'alias': 'ATL',
            'nano': 'mLspw4gJNTQGN',
        },
        'atlanta-falcons': {
            'market': 'Atlanta',
            'name': 'Falcons',
            'alias': 'ATL',
            'nano': 'mLspw4gJNTQGN',
        },
        'falcons': {
            'market': 'Atlanta',
            'name': 'Falcons',
            'alias': 'ATL',
            'nano': 'mLspw4gJNTQGN',
        },
        'atl': {
            'market': 'Atlanta',
            'name': 'Falcons',
            'alias': 'ATL',
            'nano': 'mLspw4gJNTQGN',
        },
        'baltimore': {
            'market': 'Baltimore',
            'name': 'Ravens',
            'alias': 'BAL',
            'nano': 'zyhFXj1nywrm1',
        },
        'baltimore-ravens': {
            'market': 'Baltimore',
            'name': 'Ravens',
            'alias': 'BAL',
            'nano': 'zyhFXj1nywrm1',
        },
        'ravens': {
            'market': 'Baltimore',
            'name': 'Ravens',
            'alias': 'BAL',
            'nano': 'zyhFXj1nywrm1',
        },
        'bal': {
            'market': 'Baltimore',
            'name': 'Ravens',
            'alias': 'BAL',
            'nano': 'zyhFXj1nywrm1',
        },
        'rav': {
            'market': 'Baltimore',
            'name': 'Ravens',
            'alias': 'BAL',
            'nano': 'zyhFXj1nywrm1',
        },
        'buffalo': {
            'market': 'Buffalo',
            'name': 'Bills',
            'alias': 'BUF',
            'nano': '3VqeLK0LS9rpw',
        },
        'buffalo-bills': {
            'market': 'Buffalo',
            'name': 'Bills',
            'alias': 'BUF',
            'nano': '3VqeLK0LS9rpw',
        },
        'bills': {
            'market': 'Buffalo',
            'name': 'Bills',
            'alias': 'BUF',
            'nano': '3VqeLK0LS9rpw',
        },
        'buf': {
            'market': 'Buffalo',
            'name': 'Bills',
            'alias': 'BUF',
            'nano': '3VqeLK0LS9rpw',
        },
        'carolina': {
            'market': 'Carolina',
            'name': 'Panthers',
            'alias': 'CAR',
            'nano': 'jJBGuksuDJF5L',
        },
        'carolina-panthers': {
            'market': 'Carolina',
            'name': 'Panthers',
            'alias': 'CAR',
            'nano': 'jJBGuksuDJF5L',
        },
        'panthers': {
            'market': 'Carolina',
            'name': 'Panthers',
            'alias': 'CAR',
            'nano': 'jJBGuksuDJF5L',
        },
        'car': {
            'market': 'Carolina',
            'name': 'Panthers',
            'alias': 'CAR',
            'nano': 'jJBGuksuDJF5L',
        },
        'chicago': {
            'market': 'Chicago',
            'name': 'Bears',
            'alias': 'CHI',
            'nano': '1vVmWGzUZ1rea',
        },
        'chicago-bears': {
            'market': 'Chicago',
            'name': 'Bears',
            'alias': 'CHI',
            'nano': '1vVmWGzUZ1rea',
        },
        'bears': {
            'market': 'Chicago',
            'name': 'Bears',
            'alias': 'CHI',
            'nano': '1vVmWGzUZ1rea',
        },
        'chi': {
            'market': 'Chicago',
            'name': 'Bears',
            'alias': 'CHI',
            'nano': '1vVmWGzUZ1rea',
        },
        'cincinnati': {
            'market': 'Cincinnati',
            'name': 'Bengals',
            'alias': 'CIN',
            'nano': '22ZdibiqvfA2D',
        },
        'cincinnati-bengals': {
            'market': 'Cincinnati',
            'name': 'Bengals',
            'alias': 'CIN',
            'nano': '22ZdibiqvfA2D',
        },
        'bengals': {
            'market': 'Cincinnati',
            'name': 'Bengals',
            'alias': 'CIN',
            'nano': '22ZdibiqvfA2D',
        },
        'cin': {
            'market': 'Cincinnati',
            'name': 'Bengals',
            'alias': 'CIN',
            'nano': '22ZdibiqvfA2D',
        },
        'cleveland': {
            'market': 'Cleveland',
            'name': 'Browns',
            'alias': 'CLE',
            'nano': 'IR4gIYmh269EI',
        },
        'cleveland-browns': {
            'market': 'Cleveland',
            'name': 'Browns',
            'alias': 'CLE',
            'nano': 'IR4gIYmh269EI',
        },
        'browns': {
            'market': 'Cleveland',
            'name': 'Browns',
            'alias': 'CLE',
            'nano': 'IR4gIYmh269EI',
        },
        'cle': {
            'market': 'Cleveland',
            'name': 'Browns',
            'alias': 'CLE',
            'nano': 'IR4gIYmh269EI',
        },
        'dallas': {
            'market': 'Dallas',
            'name': 'Cowboys',
            'alias': 'DAL',
            'nano': 'KdjU81i7YSFE7',
        },
        'dallas-cowboys': {
            'market': 'Dallas',
            'name': 'Cowboys',
            'alias': 'DAL',
            'nano': 'KdjU81i7YSFE7',
        },
        'cowboys': {
            'market': 'Dallas',
            'name': 'Cowboys',
            'alias': 'DAL',
            'nano': 'KdjU81i7YSFE7',
        },
        'dal': {
            'market': 'Dallas',
            'name': 'Cowboys',
            'alias': 'DAL',
            'nano': 'KdjU81i7YSFE7',
        },
        'denver': {
            'market': 'Denver',
            'name': 'Broncos',
            'alias': 'DEN',
            'nano': '6DclFuycdPaOB',
        },
        'denver-broncos': {
            'market': 'Denver',
            'name': 'Broncos',
            'alias': 'DEN',
            'nano': '6DclFuycdPaOB',
        },
        'broncos': {
            'market': 'Denver',
            'name': 'Broncos',
            'alias': 'DEN',
            'nano': '6DclFuycdPaOB',
        },
        'den': {
            'market': 'Denver',
            'name': 'Broncos',
            'alias': 'DEN',
            'nano': '6DclFuycdPaOB',
        },
        'detroit': {
            'market': 'Detroit',
            'name': 'Lions',
            'alias': 'DET',
            'nano': 'FCuH1wdksA2DQ',
        },
        'detroit-lions': {
            'market': 'Detroit',
            'name': 'Lions',
            'alias': 'DET',
            'nano': 'FCuH1wdksA2DQ',
        },
        'lions': {
            'market': 'Detroit',
            'name': 'Lions',
            'alias': 'DET',
            'nano': 'FCuH1wdksA2DQ',
        },
        'det': {
            'market': 'Detroit',
            'name': 'Lions',
            'alias': 'DET',
            'nano': 'FCuH1wdksA2DQ',
        },
        'green-bay': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },
        'green-bay-packers': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },
        'greenbay': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },
        'packers': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },
        'gb': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },
        'gnb': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },
        'houston': {
            'market': 'Houston',
            'name': 'Texans',
            'alias': 'HOU',
            'nano': 'UI0Ax4HUEXFh6',
        },
        'houston-texans': {
            'market': 'Houston',
            'name': 'Texans',
            'alias': 'HOU',
            'nano': 'UI0Ax4HUEXFh6',
        },
        'texans': {
            'market': 'Houston',
            'name': 'Texans',
            'alias': 'HOU',
            'nano': 'UI0Ax4HUEXFh6',
        },
        'hou': {
            'market': 'Houston',
            'name': 'Texans',
            'alias': 'HOU',
            'nano': 'UI0Ax4HUEXFh6',
        },
        'htx': {
            'market': 'Houston',
            'name': 'Texans',
            'alias': 'HOU',
            'nano': 'UI0Ax4HUEXFh6',
        },
        'indianapolis': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },
        'indianapolis-colts': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },
        'baltimore-colts': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },
        'colts': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },
        'ind': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },
        'clt': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },
        'jacksonville': {
            'market': 'Jacksonville',
            'name': 'Jaguars',
            'alias': 'IND',
            'nano': 'RtOjnciWkJPaL',
        },
        'jacksonville-jaguars': {
            'market': 'Jacksonville',
            'name': 'Jaguars',
            'alias': 'JAC',
            'nano': 'RtOjnciWkJPaL',
        },
        'jaguars': {
            'market': 'Jacksonville',
            'name': 'Jaguars',
            'alias': 'JAC',
            'nano': 'RtOjnciWkJPaL',
        },
        'jac': {
            'market': 'Jacksonville',
            'name': 'Jaguars',
            'alias': 'JAC',
            'nano': 'RtOjnciWkJPaL',
        },
        'jax': {
            'market': 'Jacksonville',
            'name': 'Jaguars',
            'alias': 'JAC',
            'nano': 'RtOjnciWkJPaL',
        },
        'kansas-city': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'kansas-city-chiefs': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'kansascity': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'chiefs': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'kc': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'kan': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'las-vegas': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'las-vegas-raiders': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'los-angeles-raiders': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'oakland-raiders': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'raiders': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'lasvegas': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'oakland': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'lvr': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'lv': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'oak': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'rai': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },
        'los-angeles-chargers': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },
        'san-diego-chargers': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },
        'chargers': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },
        'sdg': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },
        'sd': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },
        'lac': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },
        'los-angeles-rams': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'st-louis-rams': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'st-louis': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'rams': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'ram': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'stl': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'lar': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'la': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'miami': {
            'market': 'Miami',
            'name': 'Dolphins',
            'alias': 'MIA',
            'nano': 'mfbu6O5aMHbJg',
        },
        'miami-dolphins': {
            'market': 'Miami',
            'name': 'Dolphins',
            'alias': 'MIA',
            'nano': 'mfbu6O5aMHbJg',
        },
        'dolphins': {
            'market': 'Miami',
            'name': 'Dolphins',
            'alias': 'MIA',
            'nano': 'mfbu6O5aMHbJg',
        },
        'mia': {
            'market': 'Miami',
            'name': 'Dolphins',
            'alias': 'MIA',
            'nano': 'mfbu6O5aMHbJg',
        },
        'minnesota': {
            'market': 'Minnesota',
            'name': 'Vikings',
            'alias': 'MIN',
            'nano': 'AzOs5UWsXusSW',
        },
        'minnesota-vikings': {
            'market': 'Minnesota',
            'name': 'Vikings',
            'alias': 'MIN',
            'nano': 'AzOs5UWsXusSW',
        },
        'vikings': {
            'market': 'Minnesota',
            'name': 'Vikings',
            'alias': 'MIN',
            'nano': 'AzOs5UWsXusSW',
        },
        'min': {
            'market': 'Minnesota',
            'name': 'Vikings',
            'alias': 'MIN',
            'nano': 'AzOs5UWsXusSW',
        },
        'minn': {
            'market': 'Minnesota',
            'name': 'Vikings',
            'alias': 'MIN',
            'nano': 'AzOs5UWsXusSW',
        },
        'new-england': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'new-england-patriots': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'boston-patriots': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'patriots': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'ne': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'nwe': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'new-orleans': {
            'market': 'New Orleans',
            'name': 'Saints',
            'alias': 'NO',
            'nano': 'CI5mhfNa0Zqd2',
        },
        'new-orleans-saints': {
            'market': 'New Orleans',
            'name': 'Saints',
            'alias': 'NO',
            'nano': 'CI5mhfNa0Zqd2',
        },
        'saints': {
            'market': 'New Orleans',
            'name': 'Saints',
            'alias': 'NO',
            'nano': 'CI5mhfNa0Zqd2',
        },
        'no': {
            'market': 'New Orleans',
            'name': 'Saints',
            'alias': 'NO',
            'nano': 'CI5mhfNa0Zqd2',
        },
        'nor': {
            'market': 'New Orleans',
            'name': 'Saints',
            'alias': 'NO',
            'nano': 'CI5mhfNa0Zqd2',
        },
        'new-york-jets': {
            'market': 'New York',
            'name': 'Jets',
            'alias': 'NYJ',
            'nano': 'mexvMWO2v1hWn',
        },
        'jets': {
            'market': 'New York',
            'name': 'Jets',
            'alias': 'NYJ',
            'nano': 'mexvMWO2v1hWn',
        },
        'nyj': {
            'market': 'New York',
            'name': 'Jets',
            'alias': 'NYJ',
            'nano': 'mexvMWO2v1hWn',
        },
        'new-york-giants': {
            'market': 'New York',
            'name': 'Giants',
            'alias': 'NYG',
            'nano': 'n8CuHV9wbYCqF',
        },
        'giants': {
            'market': 'New York',
            'name': 'Giants',
            'alias': 'NYG',
            'nano': 'n8CuHV9wbYCqF',
        },
        'nyg': {
            'market': 'New York',
            'name': 'Giants',
            'alias': 'NYG',
            'nano': 'n8CuHV9wbYCqF',
        },
        'philadelphia': {
            'market': 'Philadelphia',
            'name': 'Eagles',
            'alias': 'PHI',
            'nano': 'hjjmgzxilGWdr',
        },
        'philadelphia-eagles': {
            'market': 'Philadelphia',
            'name': 'Eagles',
            'alias': 'PHI',
            'nano': 'hjjmgzxilGWdr',
        },
        'eagles': {
            'market': 'Philadelphia',
            'name': 'Eagles',
            'alias': 'PHI',
            'nano': 'hjjmgzxilGWdr',
        },
        'phi': {
            'market': 'Philadelphia',
            'name': 'Eagles',
            'alias': 'PHI',
            'nano': 'hjjmgzxilGWdr',
        },
        'pittsburgh': {
            'market': 'Pittsburgh',
            'name': 'Steelers',
            'alias': 'PIT',
            'nano': 'SlVgURDFI7EXX',
        },
        'pittsburgh-steelers': {
            'market': 'Pittsburgh',
            'name': 'Steelers',
            'alias': 'PIT',
            'nano': 'SlVgURDFI7EXX',
        },
        'steelers': {
            'market': 'Pittsburgh',
            'name': 'Steelers',
            'alias': 'PIT',
            'nano': 'SlVgURDFI7EXX',
        },
        'pit': {
            'market': 'Pittsburgh',
            'name': 'Steelers',
            'alias': 'PIT',
            'nano': 'SlVgURDFI7EXX',
        },
        'san-francisco': {
            'market': 'San Francisco',
            'name': '49ers',
            'alias': 'SF',
            'nano': 'IwSI92ZDKoazn',
        },
        'san-francisco-49ers': {
            'market': 'San Francisco',
            'name': '49ers',
            'alias': 'SF',
            'nano': 'IwSI92ZDKoazn',
        },
        '49ers': {
            'market': 'San Francisco',
            'name': '49ers',
            'alias': 'SF',
            'nano': 'IwSI92ZDKoazn',
        },
        'sf': {
            'market': 'San Francisco',
            'name': '49ers',
            'alias': 'SF',
            'nano': 'IwSI92ZDKoazn',
        },
        'sfo': {
            'market': 'San Francisco',
            'name': '49ers',
            'alias': 'SF',
            'nano': 'IwSI92ZDKoazn',
        },
        'seattle': {
            'market': 'Seattle',
            'name': 'Seahawks',
            'alias': 'SEA',
            'nano': '4M8AK5p0WXs1N',
        },
        'seattle-seahawks': {
            'market': 'Seattle',
            'name': 'Seahawks',
            'alias': 'SEA',
            'nano': '4M8AK5p0WXs1N',
        },
        'seahawks': {
            'market': 'Seattle',
            'name': 'Seahawks',
            'alias': 'SEA',
            'nano': '4M8AK5p0WXs1N',
        },
        'sea': {
            'market': 'Seattle',
            'name': 'Seahawks',
            'alias': 'SEA',
            'nano': '4M8AK5p0WXs1N',
        },
        'tampa-bay': {
            'market': 'Tampa Bay',
            'name': 'Buccaneers',
            'alias': 'TB',
            'nano': 'QMAZH1v922YLu',
        },
        'tampa-bay-buccaneers': {
            'market': 'Tampa Bay',
            'name': 'Buccaneers',
            'alias': 'TB',
            'nano': 'QMAZH1v922YLu',
        },
        'buccaneers': {
            'market': 'Tampa Bay',
            'name': 'Buccaneers',
            'alias': 'TB',
            'nano': 'QMAZH1v922YLu',
        },
        'tb': {
            'market': 'Tampa Bay',
            'name': 'Buccaneers',
            'alias': 'TB',
            'nano': 'QMAZH1v922YLu',
        },
        'tam': {
            'market': 'Tampa Bay',
            'name': 'Buccaneers',
            'alias': 'TB',
            'nano': 'QMAZH1v922YLu',
        },
        'tennessee': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'tennessee-titans': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'houston-oilers': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'tennessee-oilers': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'oilers': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'titans': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'ten': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'oti': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'washington': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'washington-football-team': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'washington-commanders': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'washington-redskins': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'football-team': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'football team': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'redskins': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'commanders': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'wft': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'was': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
        'wsh': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
    }


def _splits_tms():

    return {
        'crd': {
            'market': 'Arizona',
            'name': 'Cardinals',
            'alias': 'ARI',
            'nano': 'GJizlkzQFaqGA',
        },
        'atl': {
            'market': 'Atlanta',
            'name': 'Falcons',
            'alias': 'ATL',
            'nano': 'mLspw4gJNTQGN',
        },
        'rav': {
            'market': 'Baltimore',
            'name': 'Ravens',
            'alias': 'BAL',
            'nano': 'zyhFXj1nywrm1',
        },
        'buf': {
            'market': 'Buffalo',
            'name': 'Bills',
            'alias': 'BUF',
            'nano': '3VqeLK0LS9rpw',
        },
        'car': {
            'market': 'Carolina',
            'name': 'Panthers',
            'alias': 'CAR',
            'nano': 'jJBGuksuDJF5L',
        },
        'chi': {
            'market': 'Chicago',
            'name': 'Bears',
            'alias': 'CHI',
            'nano': '1vVmWGzUZ1rea',
        },
        'cin': {
            'market': 'Cincinnati',
            'name': 'Bengals',
            'alias': 'CIN',
            'nano': '22ZdibiqvfA2D',
        },
        'cle': {
            'market': 'Cleveland',
            'name': 'Browns',
            'alias': 'CLE',
            'nano': 'IR4gIYmh269EI',
        },
        'dal': {
            'market': 'Dallas',
            'name': 'Cowboys',
            'alias': 'DAL',
            'nano': 'KdjU81i7YSFE7',
        },
        'den': {
            'market': 'Denver',
            'name': 'Broncos',
            'alias': 'DEN',
            'nano': '6DclFuycdPaOB',
        },
        'det': {
            'market': 'Detroit',
            'name': 'Lions',
            'alias': 'DET',
            'nano': 'FCuH1wdksA2DQ',
        },
        'gnb': {
            'market': 'Green Bay',
            'name': 'Packers',
            'alias': 'GB',
            'nano': 'D5QY6bOxfn8ZL',
        },   
        'htx': {
            'market': 'Houston',
            'name': 'Texans',
            'alias': 'HOU',
            'nano': 'UI0Ax4HUEXFh6',
        },
        'clt': {
            'market': 'Indianapolis',
            'name': 'Colts',
            'alias': 'IND',
            'nano': 'LJmHetie5VbbO',
        },    
        'jax': {
            'market': 'Jacksonville',
            'name': 'Jaguars',
            'alias': 'JAC',
            'nano': 'RtOjnciWkJPaL',
        },
        'kan': {
            'market': 'Kansas City',
            'name': 'Chiefs',
            'alias': 'KC',
            'nano': 'oiGiwWPf0UqMC',
        },
        'rai': {
            'market': 'Las Vegas',
            'name': 'Raiders',
            'alias': 'LV',
            'nano': 'LZoDld8s63xUs',
        },     
        'sdg': {
            'market': 'Los Angeles',
            'name': 'Chargers',
            'alias': 'LAC',
            'nano': 'SjaMbkmeizJD4',
        },  
        'ram': {
            'market': 'Los Angeles',
            'name': 'Rams',
            'alias': 'LA',
            'nano': 'u98I1lDKQBwZ0',
        },
        'mia': {
            'market': 'Miami',
            'name': 'Dolphins',
            'alias': 'MIA',
            'nano': 'mfbu6O5aMHbJg',
        },
        'min': {
            'market': 'Minnesota',
            'name': 'Vikings',
            'alias': 'MIN',
            'nano': 'AzOs5UWsXusSW',
        },
        'nwe': {
            'market': 'New England',
            'name': 'Patriots',
            'alias': 'NE',
            'nano': 'VkxV91RtzHn65',
        },
        'nor': {
            'market': 'New Orleans',
            'name': 'Saints',
            'alias': 'NO',
            'nano': 'CI5mhfNa0Zqd2',
        },
        'nyj': {
            'market': 'New York',
            'name': 'Jets',
            'alias': 'NYJ',
            'nano': 'mexvMWO2v1hWn',
        },
        'nyg': {
            'market': 'New York',
            'name': 'Giants',
            'alias': 'NYG',
            'nano': 'n8CuHV9wbYCqF',
        },
        'phi': {
            'market': 'Philadelphia',
            'name': 'Eagles',
            'alias': 'PHI',
            'nano': 'hjjmgzxilGWdr',
        },
        'pit': {
            'market': 'Pittsburgh',
            'name': 'Steelers',
            'alias': 'PIT',
            'nano': 'SlVgURDFI7EXX',
        },
        'sfo': {
            'market': 'San Francisco',
            'name': '49ers',
            'alias': 'SF',
            'nano': 'IwSI92ZDKoazn',
        },
        'sea': {
            'market': 'Seattle',
            'name': 'Seahawks',
            'alias': 'SEA',
            'nano': '4M8AK5p0WXs1N',
        },
        'tam': {
            'market': 'Tampa Bay',
            'name': 'Buccaneers',
            'alias': 'TB',
            'nano': 'QMAZH1v922YLu',
        },
        'oti': {
            'market': 'Tennessee',
            'name': 'Titans',
            'alias': 'TEN',
            'nano': 'ltMyRE3yvVUaw',
        },
        'was': {
            'market': 'Washington',
            'name': 'Football Team',
            'alias': 'WAS',
            'nano': '9JtBk8kFeaGEs',
        },
    }